@@ -5,4 +5,8 @@ from reamber.o2jam.O2JNoteObjMeta import O2JNoteObjMeta
 
 @dataclass
 class O2JHitObj(HitObj, O2JNoteObjMeta):
+    """ Defines the O2Jam Hit Object
+
+    The O2Jam Hit Object is stored in binary file .ojn
+    """
     pass
