@@ -11,12 +11,26 @@ log = logging.getLogger(__name__)
 
 @dataclass
 class O2JMapSetObj(O2JMapSetObjMeta):
-    """ We won't support OJM for now, we'll just deal with OJN since it's much easier. """
+    """ This holds all data of OJN with a few exceptions
+
+    Exceptions:
+     - Cover Data
+     - Key Sounds Data + Placement
+
+    This also doesn't support OJM (IO) and OJN (O).
+
+    OJM is not supported due to its complexity. OJN writing isn't supported due to lack of support.
+
+    We won't support OJM for now, we'll just deal with OJN since it's much easier. """
 
     maps: List[O2JMapObj] = field(default_factory=lambda: [])
 
-    # noinspection PyUnresolvedReferences
     def readFile(self, filePath: str):
+        """ Reads the OJN file. Do not load the OJM file.
+
+        :param filePath: Path to the ojn file.
+        """
+
         with open(filePath, "rb") as f:
             self.readMeta(f.read(300))
 
