@@ -10,14 +10,17 @@ class OsuSvObj(OsuTimingPointMeta, TimedObj):
 
     @staticmethod
     def codeToValue(code: float) -> float:
+        """ Converts the data in the .osu file to the actual SV Value """
         return -100.0 / code
 
     @staticmethod
     def valueToCode(value: float) -> float:
+        """ Converts the actual SV Value to a writable float in .osu """
         return -100.0 / value
 
     @staticmethod
     def readString(s: str) -> OsuSvObj or None:
+        """ Reads a single line under the [TimingPoints] Label. This must explicitly be a BPM Point. """
         if s.isspace():
             return None
 
@@ -26,6 +29,7 @@ class OsuSvObj(OsuTimingPointMeta, TimedObj):
             return None
 
         this = OsuSvObj()
+        assert sComma[6] == '0', "Unexpected BPM Object in OsuSvObj."
         this.offset = float(sComma[0])
         this.multiplier = OsuSvObj.codeToValue(float(sComma[1]))
         this.sampleSet = int(sComma[3])
@@ -36,6 +40,7 @@ class OsuSvObj(OsuTimingPointMeta, TimedObj):
         return this
 
     def writeString(self) -> str:
+        """ Exports a .osu writable string """
         return f"{int(self.offset)},{self.valueToCode(self.multiplier)}," \
                f"4,{self.sampleSet}," \
                f"{self.sampleSetIndex},{self.volume},{0},{int(self.kiai)}"
