@@ -1,3 +1,4 @@
+from __future__ import annotations
 from reamber.base.lists.notes.NoteList import NoteList
 from typing import List, Type
 from abc import ABC
@@ -7,7 +8,12 @@ from reamber.quaver.QuaNoteObjMeta import QuaNoteObjMeta
 
 class QuaNoteList(NoteList, ABC):
 
-    def _upcast(self, objList: List = None):
+    def _upcast(self, objList: List = None) -> QuaNoteList:
+        """ This is to facilitate inherited functions to work
+
+        :param objList: The List to cast
+        :rtype: QuaNoteList
+        """
         return QuaNoteList(objList)
 
     def data(self) -> List[Type[QuaNoteObjMeta]]: pass
